@@ -1,6 +1,6 @@
 /* client.c
  *
- * $Id: client.c,v 1.81 1999/12/12 19:00:49 nisse Exp $ */
+ * $Id: client.c,v 1.83 2000/02/02 23:51:03 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -60,7 +60,7 @@
      (name accept_service_handler)
      (super packet_handler)
      (vars
-       (service simple int)
+       (service simple UINT32)
        (c object command_continuation)
        ;; Do we really need the exception handler here?
        (e object exception_handler)))
@@ -74,8 +74,8 @@ do_accept_service(struct packet_handler *c,
   CAST(accept_service_handler, closure, c);
 
   struct simple_buffer buffer;
-  int msg_number;
-  int name;
+  unsigned msg_number;
+  UINT32 name;
 
   simple_buffer_init(&buffer, packet->length, packet->data);
   
@@ -104,7 +104,7 @@ do_accept_service(struct packet_handler *c,
 }
 
 struct packet_handler *
-make_accept_service_handler(int service,
+make_accept_service_handler(UINT32 service,
 			    struct command_continuation *c,
 			    struct exception_handler *e)
 {
@@ -232,7 +232,7 @@ do_exit_status(struct channel_request *c,
 	       struct simple_buffer *args)
 {
   CAST(exit_handler, closure, c);
-  int status;
+  UINT32 status;
 
   if (!want_reply
       && parse_uint32(args, &status)
@@ -263,7 +263,7 @@ do_exit_signal(struct channel_request *c,
 {
   CAST(exit_handler, closure, c);
 
-  int signal;
+  UINT32 signal;
   int core;
 
   UINT8 *msg;
