@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: client.h,v 1.25 1999/12/14 19:45:50 nisse Exp $ */
+ * $Id: client.h,v 1.26 2000/02/02 23:51:04 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -44,7 +44,7 @@ struct read_handler *make_client_read_line(struct ssh_connection *c);
 struct close_callback *make_client_close_handler(void);
 
 struct packet_handler *
-make_accept_service_handler(int service,
+make_accept_service_handler(UINT32 service,
 			    struct command_continuation *c,
 			    struct exception_handler *e);
 
