@@ -1,6 +1,6 @@
 /* command.h
  *
- * $Id: command.h,v 1.40 1999/12/31 00:41:48 nisse Exp $ */
+ * $Id: command.h,v 1.41 2000/02/02 22:33:21 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -73,6 +73,12 @@
 #define COMMAND_SIMPLE_CALL(f, a) \
   ((f)->call_simple((f), (struct lsh_object *)(a)))
 
+#define STATIC_COMMAND(f) { STATIC_HEADER, f }
+
+#define STATIC_COMMAND_SIMPLE(f) \
+{ STATIC_COMMAND(do_call_simple_command), f}
+
+
 #define COMMAND_SIMPLE(cname)				\
 static struct lsh_object *				\
 do_simple_##cname(struct command_simple *s UNUSED,	\
@@ -90,11 +96,6 @@ void do_call_simple_command(struct command *s,
 			    struct command_continuation *c,
 			    struct exception_handler *e);
 
-#define STATIC_COMMAND_SIMPLE(f) \
-{ { STATIC_HEADER, do_call_simple_command }, f}
-
-#define STATIC_COMMAND(f) { STATIC_HEADER, f }
-
 struct command *make_parallell_progn(struct object_list *body);
 extern struct command_simple progn_command;
 
