@@ -1,6 +1,6 @@
 /* exception.h
  *
- * $Id: exception.h,v 1.14 1999/12/07 21:57:49 nisse Exp $ */
+ * $Id: exception.h,v 1.15 2000/01/12 22:54:01 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -135,6 +135,13 @@ void exception_raise(struct exception_handler *e,
 /* Unexpected or unsupported expression type */
 #define EXC_SPKI_TYPE 0x80001
 
+#if 0
+/* Serialization */
+#define EXC_CONNECTION_SERIALIZE 0x100000
+#define EXC_CONNECTION_LOCK 0x100001
+#define EXC_CONNECTION_UNLOCK 0x100002
+#endif
+
 #define EXC_ALL (~0)
 
 extern struct exception_handler default_exception_handler;
