@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.87 2000/01/26 18:35:20 nisse Exp $ */
+ * $Id: io.c,v 1.88 2000/02/02 22:34:00 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -615,7 +615,7 @@ static void init_file(struct io_backend *b, struct lsh_fd *f, int fd,
 
 int blocking_read(int fd, struct read_handler *handler)
 {  
-  char *buffer = alloca(BLOCKING_READ_SIZE);
+  UINT8 *buffer = alloca(BLOCKING_READ_SIZE);
   
   for (;;)
     {
@@ -644,6 +644,7 @@ int blocking_read(int fd, struct read_handler *handler)
 	    done += READ_HANDLER(handler, got - done, buffer + done);
 	}
     }
+  /* FIXME: Not reached. Hmm. */
   close(fd);
   return !handler;
 }
