@@ -1,6 +1,6 @@
 /* proxy.h
  *
- * $Id: proxy.h,v 1.1 1999/11/29 20:53:51 nisse Exp $ */
+ * $Id: proxy.h,v 1.2 2000/01/12 22:40:12 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -30,6 +30,11 @@
 extern struct collect_info_1 chain_connections;
 
 struct command *
-make_proxy_connection_service(struct alist *session_requests);
+make_proxy_connection_service(struct alist *server_requests,
+			      struct alist *client_requests);
+
+struct command *
+make_proxy_offer_service(struct alist *services);
+
 
 #endif /* LSH_PROXY_H_INCLUDED */
