@@ -2,7 +2,7 @@
  *
  * An implementation of Ron Rivest's S-expressions, used in spki.
  *
- * $Id: sexp.c,v 1.23 1999/11/28 23:20:05 nisse Exp $ */
+ * $Id: sexp.c,v 1.24 1999/12/20 18:58:27 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -720,7 +720,7 @@ int sexp_atomp(const struct sexp *e)
 struct lsh_string *
 sexp2string(struct sexp *e)
 {
-  return (e && (sexp_atomp(e) && !sexp_display(e))
+  return ( (e && sexp_atomp(e) && !sexp_display(e))
 	   ? sexp_contents(e) : NULL);
 }
   
